#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.2
id: yesod-1.4.2-e3cfca29f46f8b6000cb16644ffed4e6
key: yesod_14ALZ9eeGm95uw14QKy2Hr
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2 Yesod.Default.Main
    Yesod.Default.Util Yesod.Default.Handlers
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
hs-libraries: HSyesod-1.4.2-14ALZ9eeGm95uw14QKy2Hr
depends:
    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-extra-1.1.9.3-79f96334aec0357c74e6e80c98ebd34c
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-5b0e343fa2336db43bff88fa9ebe3732
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
    shakespeare-2.0.7-3d8247ff57d7f10558308bd73d118ae2
    streaming-commons-0.1.15.1-aa72527d91e580265833d7825d2659ed
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
    wai-3.2.0-4a83d89b48e41e4313efb14d081e93b7
    wai-extra-3.0.13.1-7efedccfcc7a18964cfd2ae8c68f8b44
    wai-logger-2.2.4.1-1a63888d405f0912f2c2b9211c9684ae
    warp-3.2.1-9f80804598ddc4025ca5d80c0dec839f
    yaml-0.8.16-010f15330a70bef2b858dbbfe897d8b2
    yesod-auth-1.4.12-e90c8882b973d4550fb7643fd17e2ea5
    yesod-core-1.4.19-26be2cd4fab3590d50215918542039ea
    yesod-form-1.4.6-b7ea076fcdf26efdea60d10e1858f139
    yesod-persistent-1.4.0.3-a74bc52c5eba2a36d1b7e7a1c0552522
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
